@echo off

rem
rem Copyright (c) 2004-2008,2012-2013 Progress Software Corporation. All Rights Reserved.
rem Copyright (c) 2013-2019, 2021-2022 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.
rem Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
rem
rem Defines the Apama runtime environment. Can be used to run a single command without setting the parent environment
rem
rem Usage:
rem
rem  apama_env
rem
rem  apama_env correlator --config myproject

rem 
rem Please note the use of goto rather than nested ifs is by design, to avoid numerous issues 
rem batch scripts have when variable values may contain parentheses (e.g. "Program Files (x86)")
rem 

if not "%~1" == "" ( setlocal )
if "%~1" == "--help" ( goto PRINTUSAGE )
if "%~1" == "-h"     ( goto PRINTUSAGE )
if "%~1" == "/?"     ( goto PRINTUSAGE )

set APAMA_DIR=%~dp0..

rem
rem If this script already called to setup environment do nothing. This is to
rem prevent duplication in path settings.
rem

if not defined APAMA_ENVSET (goto DEFINEENV)

if "%APAMA_ENVSET%" == "10.15:%APAMA_DIR%:amd64-win" ( goto MAYBEEXEC)

rem Print a warning to stderr and continue
echo WARNING: Apama environment already defined for a different installation, version or platform. 1>&2
echo Cannot redefine environment - use a clean shell. 1>&2
echo Continuing to use installation in %APAMA_HOME% 1>&2
goto MAYBEEXEC

:PRINTUSAGE
echo Usage: apama_env.bat ^<command^> [^<argument^>...]
exit /b 0

:DEFINEENV

rem allow APAMA_HOME to be overridden by setting it in the environment before 
rem calling the script
if not defined APAMA_HOME set "APAMA_HOME=%APAMA_DIR%"

set APAMA_ENVSET=10.15:%APAMA_HOME%:amd64-win

if "%~1" == "" (
echo.
echo Defining Apama 10.15 runtime environment.
echo.
)
set APAMA_LIBRARY_VERSION=10.15
set APAMA_PLATFORM=amd64-win

rem Warning about JAVA_HOME not being set
if not defined JAVA_HOME if "%~1" == "" echo WARNING: JAVA_HOME not set, Java functionality disabled

rem JRE_HOME from JAVA_HOME if not set
if not defined JRE_HOME set "JRE_HOME=%JAVA_HOME%"

if not defined APAMA_JRE set "APAMA_JRE=%JRE_HOME%"

if not defined APAMA_WORK set "APAMA_WORK=%PUBLIC%\SoftwareAG\ApamaWork_10.15"
if not exist "%APAMA_WORK%" mkdir %APAMA_WORK%
if not exist "%APAMA_WORK%\lib" mkdir %APAMA_WORK%\lib

set PATH=%APAMA_WORK%\lib;%APAMA_HOME%\bin;%APAMA_JRE%\bin\server;%APAMA_JRE%\bin;%ANT_HOME%\bin;%APAMA_JRE%\..\bin;%PATH%

set PYTHONPATH=%PYTHONPATH%;%APAMA_HOME%\third_party\python\Lib\site-packages

rem Sets SSL_CERT_FILE to default only if not explicitly set by user
if not defined SSL_CERT_FILE (
	set SSL_CERT_FILE=%APAMA_HOME%\etc\cert.pem
)

rem Allow user/dev to explicitly NOT set the file & will only warn if user declares a file that does not exist
if "%SSL_CERT_FILE%"=="none" (
	set SSL_CERT_FILE=
) else (
	if not exist "%SSL_CERT_FILE%" (
		if "%~1" == "" echo WARNING: SSL_CERT_FILE does not exist
	)
)

:MAYBEEXEC
if "%~1" == "" goto END

rem Execute the specified command
%* 
endlocal 
exit /b %ERRORLEVEL%

:END
set APAMA_DIR=

