/*
 * Title:        sag_connectivity_cpp.hpp
 * Description:  C++ header-only wrapper for C-ABI data_t type
 * $Copyright (c) 2015-2018, 2020, 2022 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 */

/** @file
 *
 * Contains the C++ implementation of the underlying datatypes used by connectivity plugins and their accessors
 *
 */

/*
	NB: This uses a C ABI under the hood, but should be manipulated via the classes in this file.
*/

#ifndef _CPPMESSAGEDATA_H_
#define _CPPMESSAGEDATA_H_

#include <sag_connectivity_c.h>
#include <algorithm>
#include <stdexcept>
#include <cstddef>
#include <cinttypes>
#include <stddef.h>
#include <assert.h>
#include <string>
#include <sstream>
#include <typeinfo>
#include <string.h>
#include <vector>
#include <unordered_set>
#include <inttypes.h>

// internal implementation
#include <sag_internal/cpp_stdlib.hpp>

// make sure bits/*.hpp can only be included from here
#define _DATAT_BITS_INCLUDE_TAG

#include <sag_internal/connectivity_namespace_version.h>

namespace com { 
namespace softwareag {
/** 
 * Contains classes relating to the connectivity system.
 */
namespace _DATAT_INTERNAL_CPP_NAMESPACE { 

class list_t;
class map_t;
class buffer_t;
template<typename T> class custom_t;

/** Decimals are implemented with an underlying 64bit int conforming to IEEE
	754 decimal 64. This struct only provides access to the 64 bit data, which can be accessed with a 64-bit decimal
	library in order to perform arithmetic or convert to / from strings. */
typedef sag_underlying_decimal_t decimal_t;


// include all the sub-files for the individual types

#include <bits/data_t.hpp>

#include <bits/custom_t.hpp>

#include <bits/functions.hpp>

#include <bits/buffer_t.hpp>

#include <bits/list_t.hpp>

#include <bits/map_t.hpp>

#include <bits/metadata_t.hpp>

#include <bits/message.hpp>

#include <bits/visitors.hpp>

#include <bits/map_extractor.hpp>

}
/** 
 * Contains classes relating to the connectivity system.
 */
namespace connectivity { using namespace _DATAT_INTERNAL_CPP_NAMESPACE; }

}} // com.softwareag.connectivity

// internal implementation details in here
#include <sag_internal/data.hpp>

// make sure bits/*.hpp can only be included from here
#undef _DATAT_BITS_INCLUDE_TAG

#endif // _CPPMESSAGEDATA_H_
